@@ -3,8 +3,8 @@
 ;; Copyright (C) 2024-2026 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti
-;; Package-Version: 20260209.1631
-;; Package-Revision: 63ff86eab61f
+;; Package-Version: 20260212.2003
+;; Package-Revision: 262cf10e51c0
 ;; URL: https://github.com/jamescherti/buffer-terminator.el
 ;; Keywords: convenience
 ;; Package-Requires: ((emacs "25.1"))
@@ -84,8 +84,12 @@ Default: 30 minutes."
   :group 'buffer-terminator)
 
 (defcustom buffer-terminator-verbose nil
-  "Enable verbose mode to log when a buffer is automatically killed."
-  :type 'boolean
+  "Non-nil means log a message when a buffer is automatically killed.
+If t, display the message in the echo area and the *Messages* buffer.
+If \='inhibit-message, log only to the *Messages* buffer."
+  :type '(choice (const :tag "Disabled" nil)
+                 (const :tag "Full Verbose (Echo Area and Log)" t)
+                 (const :tag "Log Only (Inhibit Echo Area)" inhibit-message))
   :group 'buffer-terminator)
 
 (defvar buffer-terminator--kill-inactive-buffers-timer nil
@@ -582,9 +586,13 @@ Returns non-nil if the buffer was successfully killed, otherwise nil."
       (when result
         (buffer-terminator--debug-message "Terminated the buffer: '%s'"
                                           buffer-name)
-        (when buffer-terminator-verbose
-          (buffer-terminator--message "Terminated the buffer: '%s'"
-                                      buffer-name)))
+        (let ((inhibit-message (if (eq buffer-terminator-verbose
+                                       'inhibit-message)
+                                   t
+                                 inhibit-message)))
+          (when buffer-terminator-verbose
+            (buffer-terminator--message "Terminated the buffer: '%s'"
+                                        buffer-name))))
       result)))
 
 (defun buffer-terminator-apply-rules (&optional rules buffers)
